pub struct State {Show 13 fields
pub active: i32,
pub current_tasks: Vec<i32>,
pub current_flows: Vec<i32>,
pub visited_tasks: Vec<i32>,
pub visited_flows: Vec<i32>,
pub pending_tasks: Vec<i32>,
pub maybe_future_tasks: Vec<i32>,
pub maybe_future_flows: Vec<i32>,
pub maybe_visited_tasks: Vec<i32>,
pub variables: JsonValue,
pub completed: bool,
pub remote_id: Option<String>,
pub remote_version: Option<i64>,
}Fields
active: i32current_tasks: Vec<i32>current_flows: Vec<i32>visited_tasks: Vec<i32>visited_flows: Vec<i32>pending_tasks: Vec<i32>maybe_future_tasks: Vec<i32>maybe_future_flows: Vec<i32>maybe_visited_tasks: Vec<i32>variables: JsonValuecompleted: boolremote_id: Option<String>remote_version: Option<i64>Trait Implementations
Sourceimpl Archive for State
impl Archive for State
Sourcetype Archived = ArchivedState
type Archived = ArchivedState
The archived representation of this type. Read more
Sourcetype Resolver = StateResolver
type Resolver = StateResolver
The resolver for this type. It must contain all the additional information from serializing
needed to make the archived type from the normal type.
Sourceimpl<__D> Deserialize<State, __D> for Archived<State>where
__D: SharedDeserializeRegistry + Fallible + ?Sized,
i32: Archive,
Archived<i32>: Deserialize<i32, __D>,
Vec<i32>: Archive,
Archived<Vec<i32>>: Deserialize<Vec<i32>, __D>,
JsonValue: Archive,
Archived<JsonValue>: Deserialize<JsonValue, __D>,
bool: Archive,
Archived<bool>: Deserialize<bool, __D>,
Option<String>: Archive,
Archived<Option<String>>: Deserialize<Option<String>, __D>,
Option<i64>: Archive,
Archived<Option<i64>>: Deserialize<Option<i64>, __D>,
impl<__D> Deserialize<State, __D> for Archived<State>where
__D: SharedDeserializeRegistry + Fallible + ?Sized,
i32: Archive,
Archived<i32>: Deserialize<i32, __D>,
Vec<i32>: Archive,
Archived<Vec<i32>>: Deserialize<Vec<i32>, __D>,
JsonValue: Archive,
Archived<JsonValue>: Deserialize<JsonValue, __D>,
bool: Archive,
Archived<bool>: Deserialize<bool, __D>,
Option<String>: Archive,
Archived<Option<String>>: Deserialize<Option<String>, __D>,
Option<i64>: Archive,
Archived<Option<i64>>: Deserialize<Option<i64>, __D>,